@@ -2,4 +2,5 @@ from .file_handlers import *
 from .file_filtering import *
 from .content_utils import *
 from .python_utils import *
-from .finderConsole import *
+from .secure_paths import *
+from .size_utils import *
