@@ -2,7 +2,7 @@ import os
 import glob
 from typing import *
 from collections import defaultdict
-from ..file_filtering.file_filters import get_files_and_dirs
+from ..file_filtering.file_filters import get_files_and_dirs, define_defaults
 #!/usr/bin/env python3
 from pathlib import PurePosixPath
 def normalize_paths(paths: Optional[Union[bool, str]] = True) -> str:
